@@ -1,7 +1,6 @@
 import requests
 from munch import munchify
 import math
-from collections import Counter
 
 class Error500(Exception):
     pass
@@ -11,6 +10,8 @@ class LootBotApi:
     def __init__(self,token):
         self.token = token
         self.endpoint = f"http://fenixweb.net:3300/api/v2/{self.token}"
+        self.items = self.get_items()
+        self.craft_needed = dict()
 
     def __request_url(self,url):
         response_json = requests.get(url).json()
@@ -21,13 +22,18 @@ class LootBotApi:
         return munchify(response_json["res"])
 
     def get_items(self,rarity = None):
-        if rarità != None:
+        if rarity != None:
             return self.get_item(rarity)
 
         return self.__request_url(f"{self.endpoint}/items")
 
     def get_item(self,item):
-        return self.__request_url(f"{self.endpoint}/items/{item}")
+        item_return = list(filter(lambda item_search: item_search.name == item, self.items))
+        if item_return == []:
+            item_return = list(filter(lambda item_search: item_search.rarity == item, self.items))
+            if item_return == []:
+                item_return = self.__request_url(f"{self.endpoint}/items/{item}")
+        return item_return
 
     def get_exact_item(self,item):
         item_api = self.get_item(item)
@@ -84,11 +90,13 @@ class LootBotApi:
         return self.__request_url(f"{self.endpoint}/shop/{shop}")
 
     def get_craft_needed(self,item_id):
-        return self.__request_url(f"{self.endpoint}/crafts/{item_id}/needed")
+        try:
+            craft_needed = self.craft_needed[item_id]
+        except KeyError:
+            craft_needed = self.__request_url(f"{self.endpoint}/crafts/{item_id}/needed")
+            self.craft_needed[item_id] = craft_needed
 
-    def get_craft_needed_base(self,item_id):
-        craft_needed = self.get_craft_needed(item_id)
-        return list(filter(lambda item : not item.craftable,craft_needed))
+        return craft_needed
 
     def get_craft_used(self,item_id):
         return self.__request_url(f"{self.endpoint}/crafts/{item_id}/used")
@@ -138,17 +146,3 @@ class LootBotApi:
                 results.append(dict_craft)
 
         return results
-
-    def get_craft_total_needed_base_items(self,item,num_elements=1):
-        def get_crafting(elemento):
-            elements_needed = self.get_craft_needed(elemento)
-            base_elements = self.get_craft_needed_base(elemento)
-
-            for element_needed in elements_needed:
-                if element_needed.craftable:
-                     base_elements.extend(get_crafting(element_needed.id))
-
-            return base_elements
-
-        # TODO: Aggiungere il numero degli elementi mancanti
-        return get_crafting(self.get_exact_item(item).id)
